import React, { useEffect, useRef, useState } from 'react';
import { StyleSheet, View, Text, Dimensions, ScrollView } from 'react-native';
import { Theme } from '../Styles/theme';
const { width: WINDOW_WIDTH, height: WINDOW_HEIGHT } = Dimensions.get('window');
const MAX_SCROLL_HEIGHT = 300;
const PickerView = props => {
    const { dataSource, selectedIndex, itemHeight, onChange } = props;
    const [showPickerItem, setShowPickItem] = useState(false);
    // ScrollView 在Modal中会影响Modal的高度计算，先让容器渲染出来，再渲染ScrollView
    useEffect(() => {
        setTimeout(() => {
            setShowPickItem(true);
        }, 50);
    }, []);
    const height = Math.min(MAX_SCROLL_HEIGHT, WINDOW_HEIGHT / 3);
    const padding = (height - itemHeight) / 2;
    const highlightStyle = {
        top: padding,
        height: itemHeight,
        width: WINDOW_WIDTH,
        borderTopColor: Theme.borderColor,
        borderBottomColor: Theme.borderColor,
        borderTopWidth: Theme.borderWidthSm,
        borderBottomWidth: Theme.borderWidthSm,
    };
    return (React.createElement(View, { style: [styles.container, { height }] }, showPickerItem
        ? dataSource.map((item, index) => (React.createElement(View, { key: index, style: [styles.picker] },
            React.createElement(View, { style: [styles.highlight, highlightStyle] }),
            React.createElement(PickerItem, { dataSource: item, selectedIndex: selectedIndex[index], itemHeight: itemHeight, onChange: i => {
                    const data = [...selectedIndex];
                    data[index] = i;
                    onChange && onChange(data);
                } }))))
        : null));
};
export default PickerView;
const PickerItem = props => {
    const { dataSource, selectedIndex, itemHeight, onChange } = props;
    const [activeIndex, setActiveIndex] = useState(selectedIndex);
    const $scroll = useRef(null);
    const isScrolling = useRef(false);
    const height = Math.min(MAX_SCROLL_HEIGHT, WINDOW_HEIGHT / 3);
    const padding = (height - itemHeight) / 2;
    const onMomentumScrollBegin = () => {
        isScrolling.current = true;
    };
    const onMomentumScrollEnd = (event) => {
        isScrolling.current = false;
        if (!isScrolling.current) {
            scrollToFix(event.nativeEvent.contentOffset.y);
        }
    };
    const scrollToFix = (y) => {
        const index = Math.round(y / itemHeight);
        const _y = index * itemHeight;
        if (y !== _y) {
            $scroll.current?.scrollTo({
                y: _y,
                animated: true,
            });
        }
        onChange && onChange(index);
    };
    useEffect(() => {
        const y = selectedIndex * itemHeight;
        $scroll.current?.scrollTo({
            y,
            animated: true,
        });
        // 高度或者index变化都需要滚动
    }, [itemHeight, selectedIndex]);
    return (React.createElement(ScrollView, { ref: $scroll, style: styles.scrollView, contentContainerStyle: styles.scrollViewContent, bounces: false, showsVerticalScrollIndicator: false, nestedScrollEnabled: true, onMomentumScrollBegin: onMomentumScrollBegin, onMomentumScrollEnd: onMomentumScrollEnd, onScroll: e => {
            const index = Math.round(e.nativeEvent.contentOffset.y / itemHeight);
            setActiveIndex(index);
        } },
        React.createElement(View, { style: [styles.placeholder, { height: padding }] }),
        dataSource.map((i, idx) => (React.createElement(View, { key: idx, style: [styles.pickerItem, { height: itemHeight }] },
            React.createElement(Text, { style: [styles.pickText, activeIndex === idx && styles.activeText] }, i)))),
        React.createElement(View, { style: [styles.placeholder, { height: padding }] })));
};
const styles = StyleSheet.create({
    container: {
        flexDirection: 'row',
        justifyContent: 'space-between',
    },
    picker: {
        flex: 1,
    },
    highlight: {
        position: 'absolute',
    },
    scrollView: {
        width: '100%',
    },
    scrollViewContent: {
        alignItems: 'center',
    },
    placeholder: {
        flex: 1,
    },
    pickerItem: {
        justifyContent: 'center',
    },
    pickText: {
        fontSize: Theme.fontSizeCaption,
        color: Theme.colorTextCaption,
    },
    activeText: {
        color: Theme.colorTextParagraph,
    },
});
