import React, { isValidElement, useEffect } from 'react';
import { StyleSheet, View, Text, Image, TouchableWithoutFeedback, } from 'react-native';
import Badge from '../Badge';
const TabBarItem = props => {
    const { title, selected = false, badge, convex = false, dot = false, icon, iconSize = 20, activeColor, inactiveColor, selectedIcon, convexBackgroundColor, onPress = () => 1, } = props;
    const renderIcon = selected ? selectedIcon : icon;
    const currentColor = selected ? activeColor : inactiveColor;
    // 提前加载图片，防止切换时导致闪动
    useEffect(() => {
        [selectedIcon, icon].forEach(image => {
            if (!isValidElement(image) && typeof image === 'string') {
                Image.prefetch(image);
            }
        });
        return () => { };
    }, [selectedIcon, icon]);
    const iconWrapSize = convex ? 56 : iconSize;
    const iconImageSize = convex ? iconSize * 1.2 : iconSize;
    return (React.createElement(TouchableWithoutFeedback, { onPress: onPress },
        React.createElement(View, { style: styles.tabBarItem },
            React.createElement(View, { style: styles.wrap },
                isValidElement(renderIcon) ? (React.createElement(React.Fragment, null, renderIcon)) : (React.createElement(View, { style: [
                        { width: iconWrapSize, height: iconWrapSize },
                        convex && { ...styles.convex, backgroundColor: convexBackgroundColor },
                    ] },
                    React.createElement(Image, { source: renderIcon, style: { width: iconImageSize, height: iconImageSize } }))),
                convex && React.createElement(View, { style: { width: iconSize, height: iconSize } }),
                React.createElement(Text, { style: [styles.title, { color: currentColor }] }, title),
                badge && React.createElement(Badge, { corner: true, text: badge, size: "small", dot: dot })))));
};
const styles = StyleSheet.create({
    tabBarItem: {
        position: 'relative',
        flex: 1,
        alignItems: 'center',
        justifyContent: 'center',
    },
    wrap: {
        position: 'relative',
        alignItems: 'center',
        justifyContent: 'center',
    },
    convex: {
        alignItems: 'center',
        justifyContent: 'center',
        position: 'absolute',
        top: -25,
        borderRadius: 28,
        padding: 10,
    },
    title: {
        fontSize: 13,
        marginTop: 4,
    },
});
export default TabBarItem;
